@@ -81,6 +81,8 @@ class CreateDjangoModel:
             return models.TimeField, {}
         if type_ == bytes:
             return models.BinaryField, dict(editable=True)
+        if type_ == bool:
+            return models.BooleanField, {}
 
         if isinstance(type_, types.GenericAlias):
             origin = tp.get_origin(type_)
